class JetpackError(Exception):
    """Base class for exceptions in this module"""

    pass


class RuntimeError(JetpackError):
    """Exception raised for errors in the Jetpack runtime and kubernetes."""

    def __init__(self, message: str) -> None:
        self.message = message


class ApplicationError(JetpackError):
    """Exception raised for errors from application-code that is using the SDK.

    TODO DEV-157
    For exceptions raised by remote functions and jobs, we serialize the
    userland exception in the backend and save it here. The userland exception
    is re-raised by the SDK for the caller of the remote function or job.
    """

    def __init__(self, message: str) -> None:
        self.message = message



import inspect

from cleo import application as cleo


class ServeCommand(cleo.Command):
    name = "serve"
    description = "Starts a server that exposes the module over the network"

    help = inspect.cleandoc(
        """
        <info>serve:</> Starts a server that exposes the module over the network

        The server is a grpc server that can be used to invoke functions and methods
        in the module.
        """
    )

    options = [
        cleo.Option(
            name="port",
            shortcut="p",
            description="Bind the network socket to this port",
        ),
    ]

    def handle(self) -> int:
        self.line_error("<error>serve: Not implemented yet.</>")
        return 0  # For now emulate success so we can write tests



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['jetpack',
 'jetpack._remote',
 'jetpack._runtime',
 'jetpack._task',
 'jetpack._util',
 'jetpack._util.network',
 'jetpack.cmd',
 'jetpack.config',
 'jetpack.console',
 'jetpack.console.commands',
 'jetpack.models',
 'jetpack.models.core',
 'jetpack.models.runtime',
 'jetpack.proto.runtime.v1alpha1']

package_data = \
{'': ['*']}

install_requires = \
['cleo>=1.0.0a4,<2.0.0',
 'click>=8.0.3,<9.0.0',
 'cronitor>=4.2.0,<5.0.0',
 'grpcio>=1.43.0,<2.0.0',
 'jsonpickle>=2.0.0,<3.0.0',
 'protobuf>=3.17.0,<4.0.0',
 'redis-namespace>=3.0.1,<4.0.0',
 'redis==3.0.1',
 'schedule>=1.1.0,<2.0.0',
 'tblib>=1.7.0,<2.0.0']

entry_points = \
{'console_scripts': ['jetpack-sdk = jetpack:run']}

setup_kwargs = {
    'name': 'jetpack-io',
    'version': '0.5.1.dev202202041643973895',
    'description': 'Python SDK for Jetpack.io',
    'long_description': '### Jetpack SDK\n',
    'author': 'jetpack.io',
    'author_email': 'hello@jetpack.io',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://www.jetpack.io',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
